# Copyright (C) 2009, 2010, 2013, 2014 Nicira Networks, Inc.
#
# Copying and distribution of this file, with or without modification,
# are permitted in any medium without royalty provided the copyright
# notice and this notice are preserved.  This file is offered as-is,
# without warranty of any kind.
#
# If tests have to be skipped while building, specify the '--without check'
# option. For example:
# rpmbuild -bb --without check rhel/openvswitch-fedora.spec

# This defines the base package name's version.

%define pkgver 2.13
%define pkgname ovn22.03

# If libcap-ng isn't available and there is no need for running OVS
# as regular user, specify the '--without libcapng'
%bcond_without libcapng

# Enable PIE, bz#955181
%global _hardened_build 1

# RHEL-7 doesn't define _rundir macro yet
# Fedora 15 onwards uses /run as _rundir
%if 0%{!?_rundir:1}
%define _rundir /run
%endif

# Build python2 (that provides python) and python3 subpackages on Fedora
# Build only python3 (that provides python) subpackage on RHEL8
# Build only python subpackage on RHEL7
%if 0%{?rhel} > 7 || 0%{?fedora}
# On RHEL8 Sphinx is included in buildroot
%global external_sphinx 1
%else
# Don't use external sphinx (RHV doesn't have optional repositories enabled)
%global external_sphinx 0
%endif

# We would see rpmlinit error - E: hardcoded-library-path in '% {_prefix}/lib'.
# But there is no solution to fix this. Using {_lib} macro will solve the
# rpmlink error, but will install the files in /usr/lib64/.
# OVN pacemaker ocf script file is copied in /usr/lib/ocf/resource.d/ovn/
# and we are not sure if pacemaker looks into this path to find the
# OVN resource agent script.
%global ovnlibdir %{_prefix}/lib

Name: %{pkgname}
Summary: Open Virtual Network support
Group: System Environment/Daemons
URL: http://www.ovn.org/
Version: 22.03.0
Release: 125%{?commit0:.%{date}git%{shortcommit0}}%{?dist}
Provides: openvswitch%{pkgver}-ovn-common = %{?epoch:%{epoch}:}%{version}-%{release}
Obsoletes: openvswitch%{pkgver}-ovn-common < 2.11.0-1

# Nearly all of openvswitch is ASL 2.0.  The bugtool is LGPLv2+, and the
# lib/sflow*.[ch] files are SISSL
License: ASL 2.0 and LGPLv2+ and SISSL

# Always pull an upstream release, since this is what we rebase to.
Source: https://github.com/ovn-org/ovn/archive/v%{version}.tar.gz#/ovn-%{version}.tar.gz

%define ovscommit c9c602b6f332c6e76b273c607366185cf28ed156
%define ovsshortcommit c9c602b

Source10: https://github.com/openvswitch/ovs/archive/%{ovscommit}.tar.gz#/openvswitch-%{ovsshortcommit}.tar.gz
%define ovsdir ovs-%{ovscommit}

%define docutilsver 0.12
%define pygmentsver 1.4
%define sphinxver   1.1.3
Source100: https://pypi.io/packages/source/d/docutils/docutils-%{docutilsver}.tar.gz
Source101: https://pypi.io/packages/source/P/Pygments/Pygments-%{pygmentsver}.tar.gz
Source102: https://pypi.io/packages/source/S/Sphinx/Sphinx-%{sphinxver}.tar.gz

Source500: configlib.sh
Source501: gen_config_group.sh
Source502: set_config.sh

# Important: source503 is used as the actual copy file
# @TODO: this causes a warning - fix it?
Source504: arm64-armv8a-linuxapp-gcc-config
Source505: ppc_64-power8-linuxapp-gcc-config
Source506: x86_64-native-linuxapp-gcc-config

Patch:     %{pkgname}.patch

# FIXME Sphinx is used to generate some manpages, unfortunately, on RHEL, it's
# in the -optional repository and so we can't require it directly since RHV
# doesn't have the -optional repository enabled and so TPS fails
%if %{external_sphinx}
BuildRequires: python3-sphinx
%else
# Sphinx dependencies
BuildRequires: python-devel
BuildRequires: python-setuptools
#BuildRequires: python2-docutils
BuildRequires: python-jinja2
BuildRequires: python-nose
#BuildRequires: python2-pygments
# docutils dependencies
BuildRequires: python-imaging
# pygments dependencies
BuildRequires: python-nose
%endif

BuildRequires: gcc gcc-c++ make
BuildRequires: autoconf automake libtool
BuildRequires: systemd-units openssl openssl-devel
BuildRequires: python3-devel python3-setuptools
BuildRequires: desktop-file-utils
BuildRequires: groff-base graphviz
BuildRequires: unbound-devel

# make check dependencies
BuildRequires: procps-ng
%if 0%{?rhel} == 8 || 0%{?fedora}
BuildRequires: python3-pyOpenSSL
%endif
BuildRequires: tcpdump

%if %{with libcapng}
BuildRequires: libcap-ng libcap-ng-devel
%endif

Requires: hostname openssl iproute module-init-tools

Requires(post): systemd-units
Requires(preun): systemd-units
Requires(postun): systemd-units

# to skip running checks, pass --without check
%bcond_without check

%description
OVN, the Open Virtual Network, is a system to support virtual network
abstraction.  OVN complements the existing capabilities of OVS to add
native support for virtual network abstractions, such as virtual L2 and L3
overlays and security groups.

%package central
Summary: Open Virtual Network support
License: ASL 2.0
Requires: %{pkgname}
Requires: firewalld-filesystem
Provides: openvswitch%{pkgver}-ovn-central = %{?epoch:%{epoch}:}%{version}-%{release}
Obsoletes: openvswitch%{pkgver}-ovn-central < 2.11.0-1

%description central
OVN DB servers and ovn-northd running on a central node.

%package host
Summary: Open Virtual Network support
License: ASL 2.0
Requires: %{pkgname}
Requires: firewalld-filesystem
Provides: openvswitch%{pkgver}-ovn-host = %{?epoch:%{epoch}:}%{version}-%{release}
Obsoletes: openvswitch%{pkgver}-ovn-host < 2.11.0-1

%description host
OVN controller running on each host.

%package vtep
Summary: Open Virtual Network support
License: ASL 2.0
Requires: %{pkgname}
Provides: openvswitch%{pkgver}-ovn-vtep = %{?epoch:%{epoch}:}%{version}-%{release}
Obsoletes: openvswitch%{pkgver}-ovn-vtep < 2.11.0-1

%description vtep
OVN vtep controller

%prep
%if 0%{?commit0:1}
%autosetup -n ovn-%{commit0} -a 10 -p 1
%else
%autosetup -n ovn-%{version} -a 10 -p 1
%endif

%build
%if 0%{?commit0:1}
# fix the snapshot unreleased version to be the released one.
sed -i.old -e "s/^AC_INIT(openvswitch,.*,/AC_INIT(openvswitch, %{version},/" configure.ac
%endif
./boot.sh

# OVN source code is now separate.
# Build openvswitch first.
# XXX Current openvswitch2.13 doesn't
# use "2.13.0" for version. It's a commit hash
pushd %{ovsdir}
./boot.sh
%configure \
%if %{with libcapng}
        --enable-libcapng \
%else
        --disable-libcapng \
%endif
        --enable-ssl \
        --with-pkidir=%{_sharedstatedir}/openvswitch/pki

make %{?_smp_mflags}
popd

# Build OVN.
# XXX OVS version needs to be updated when ovs2.13 is updated.
%configure \
        --with-ovs-source=$PWD/%{ovsdir} \
%if %{with libcapng}
        --enable-libcapng \
%else
        --disable-libcapng \
%endif
        --enable-ssl \
        --with-pkidir=%{_sharedstatedir}/openvswitch/pki

make %{?_smp_mflags}

%install
%make_install
install -p -D -m 0644 \
        rhel/usr_share_ovn_scripts_systemd_sysconfig.template \
        $RPM_BUILD_ROOT/%{_sysconfdir}/sysconfig/ovn

for service in ovn-controller ovn-controller-vtep ovn-northd; do
        install -p -D -m 0644 \
                        rhel/usr_lib_systemd_system_${service}.service \
                        $RPM_BUILD_ROOT%{_unitdir}/${service}.service
done

install -d -m 0755 $RPM_BUILD_ROOT/%{_sharedstatedir}/ovn

install -d $RPM_BUILD_ROOT%{ovnlibdir}/firewalld/services/
install -p -m 0644 rhel/usr_lib_firewalld_services_ovn-central-firewall-service.xml \
        $RPM_BUILD_ROOT%{ovnlibdir}/firewalld/services/ovn-central-firewall-service.xml
install -p -m 0644 rhel/usr_lib_firewalld_services_ovn-host-firewall-service.xml \
        $RPM_BUILD_ROOT%{ovnlibdir}/firewalld/services/ovn-host-firewall-service.xml

install -d -m 0755 $RPM_BUILD_ROOT%{ovnlibdir}/ocf/resource.d/ovn
ln -s %{_datadir}/ovn/scripts/ovndb-servers.ocf \
      $RPM_BUILD_ROOT%{ovnlibdir}/ocf/resource.d/ovn/ovndb-servers

install -p -D -m 0644 rhel/etc_logrotate.d_ovn \
        $RPM_BUILD_ROOT/%{_sysconfdir}/logrotate.d/ovn

# remove unneeded files.
rm -f $RPM_BUILD_ROOT%{_bindir}/ovs*
rm -f $RPM_BUILD_ROOT%{_bindir}/vtep-ctl
rm -f $RPM_BUILD_ROOT%{_sbindir}/ovs*
rm -f $RPM_BUILD_ROOT%{_mandir}/man1/ovs*
rm -f $RPM_BUILD_ROOT%{_mandir}/man5/ovs*
rm -f $RPM_BUILD_ROOT%{_mandir}/man5/vtep*
rm -f $RPM_BUILD_ROOT%{_mandir}/man7/ovs*
rm -f $RPM_BUILD_ROOT%{_mandir}/man8/ovs*
rm -f $RPM_BUILD_ROOT%{_mandir}/man8/vtep*
rm -rf $RPM_BUILD_ROOT%{_datadir}/ovn/python
rm -f $RPM_BUILD_ROOT%{_datadir}/ovn/scripts/ovs*
rm -rf $RPM_BUILD_ROOT%{_datadir}/ovn/bugtool-plugins
rm -f $RPM_BUILD_ROOT%{_libdir}/*.a
rm -f $RPM_BUILD_ROOT%{_libdir}/*.la
rm -f $RPM_BUILD_ROOT%{_libdir}/pkgconfig/*.pc
rm -f $RPM_BUILD_ROOT%{_includedir}/ovn/*
rm -f $RPM_BUILD_ROOT%{_sysconfdir}/bash_completion.d/ovs-appctl-bashcomp.bash
rm -f $RPM_BUILD_ROOT%{_sysconfdir}/bash_completion.d/ovs-vsctl-bashcomp.bash
rm -rf $RPM_BUILD_ROOT%{_sysconfdir}/logrotate.d/openvswitch
rm -f $RPM_BUILD_ROOT%{_datadir}/ovn/scripts/ovn-bugtool*
rm -f $RPM_BUILD_ROOT/%{_bindir}/ovn-docker-overlay-driver \
        $RPM_BUILD_ROOT/%{_bindir}/ovn-docker-underlay-driver

%check
%if %{with check}
    touch resolv.conf
    export OVS_RESOLV_CONF=$(pwd)/resolv.conf
    if ! make check TESTSUITEFLAGS='%{_smp_mflags}'; then
        cat tests/testsuite.log
        if ! make check TESTSUITEFLAGS='--recheck'; then
            cat tests/testsuite.log
            # Presently a test case - "2796: ovn -- ovn-controller incremental processing"
            # is failing on aarch64 arch. Let's not exit for this arch
            # until we figure out why it is failing.
            # Test case 93: ovn.at:12105       ovn -- ACLs on Port Groups is failing
            # repeatedly on s390x. This needs to be investigated.
            %ifnarch aarch64
            %ifnarch ppc64le
            %ifnarch s390x
                exit 1
            %endif
            %endif
            %endif
        fi
    fi
%endif

%clean
rm -rf $RPM_BUILD_ROOT

%pre central
if [ $1 -eq 1 ] ; then
    # Package install.
    /bin/systemctl status ovn-northd.service >/dev/null
    ovn_status=$?
    rpm -ql openvswitch-ovn-central > /dev/null
    if [[ "$?" = "0" && "$ovn_status" = "0" ]]; then
        # ovn-northd service is running which means old openvswitch-ovn-central
        # is already installed and it will be cleaned up. So start ovn-northd
        # service when posttrans central is called.
        touch %{_localstatedir}/lib/rpm-state/ovn-northd
    fi
fi

%pre host
if [ $1 -eq 1 ] ; then
    # Package install.
    /bin/systemctl status ovn-controller.service >/dev/null
    ovn_status=$?
    rpm -ql openvswitch-ovn-host > /dev/null
    if [[ "$?" = "0" && "$ovn_status" = "0" ]]; then
        # ovn-controller service is running which means old
        # openvswitch-ovn-host is installed and it will be cleaned up. So
        # start ovn-controller service when posttrans host is called.
        touch %{_localstatedir}/lib/rpm-state/ovn-controller
    fi
fi

%pre vtep
if [ $1 -eq 1 ] ; then
    # Package install.
    /bin/systemctl status ovn-controller-vtep.service >/dev/null
    ovn_status=$?
    rpm -ql openvswitch-ovn-vtep > /dev/null
    if [[ "$?" = "0" && "$ovn_status" = "0" ]]; then
        # ovn-controller-vtep service is running which means old
        # openvswitch-ovn-vtep is installed and it will be cleaned up. So
        # start ovn-controller-vtep service when posttrans host is called.
        touch %{_localstatedir}/lib/rpm-state/ovn-controller-vtep
    fi
fi

%preun central
%if 0%{?systemd_preun:1}
    %systemd_preun ovn-northd.service
%else
    if [ $1 -eq 0 ] ; then
        # Package removal, not upgrade
        /bin/systemctl --no-reload disable ovn-northd.service >/dev/null 2>&1 || :
        /bin/systemctl stop ovn-northd.service >/dev/null 2>&1 || :
    fi
%endif

%preun host
%if 0%{?systemd_preun:1}
    %systemd_preun ovn-controller.service
%else
    if [ $1 -eq 0 ] ; then
        # Package removal, not upgrade
        /bin/systemctl --no-reload disable ovn-controller.service >/dev/null 2>&1 || :
        /bin/systemctl stop ovn-controller.service >/dev/null 2>&1 || :
    fi
%endif

%preun vtep
%if 0%{?systemd_preun:1}
    %systemd_preun ovn-controller-vtep.service
%else
    if [ $1 -eq 0 ] ; then
        # Package removal, not upgrade
        /bin/systemctl --no-reload disable ovn-controller-vtep.service >/dev/null 2>&1 || :
        /bin/systemctl stop ovn-controller-vtep.service >/dev/null 2>&1 || :
    fi
%endif

%post
%if %{with libcapng}
if [ $1 -eq 1 ]; then
    sed -i 's:^#OVN_USER_ID=:OVN_USER_ID=:' %{_sysconfdir}/sysconfig/ovn
    sed -i 's:\(.*su\).*:\1 openvswitch openvswitch:' %{_sysconfdir}/logrotate.d/ovn
fi
%endif

%post central
%if 0%{?systemd_post:1}
    %systemd_post ovn-northd.service
%else
    # Package install, not upgrade
    if [ $1 -eq 1 ]; then
        /bin/systemctl daemon-reload >dev/null || :
    fi
%endif

%post host
%if 0%{?systemd_post:1}
    %systemd_post ovn-controller.service
%else
    # Package install, not upgrade
    if [ $1 -eq 1 ]; then
        /bin/systemctl daemon-reload >dev/null || :
    fi
%endif

%post vtep
%if 0%{?systemd_post:1}
    %systemd_post ovn-controller-vtep.service
%else
    # Package install, not upgrade
    if [ $1 -eq 1 ]; then
        /bin/systemctl daemon-reload >dev/null || :
    fi
%endif

%postun

%postun central
%if 0%{?systemd_postun_with_restart:1}
    %systemd_postun_with_restart ovn-northd.service
%else
    /bin/systemctl daemon-reload >/dev/null 2>&1 || :
    if [ "$1" -ge "1" ] ; then
    # Package upgrade, not uninstall
        /bin/systemctl try-restart ovn-northd.service >/dev/null 2>&1 || :
    fi
%endif

%postun host
%if 0%{?systemd_postun_with_restart:1}
    %systemd_postun_with_restart ovn-controller.service
%else
    /bin/systemctl daemon-reload >/dev/null 2>&1 || :
    if [ "$1" -ge "1" ] ; then
        # Package upgrade, not uninstall
        /bin/systemctl try-restart ovn-controller.service >/dev/null 2>&1 || :
    fi
%endif

%postun vtep
%if 0%{?systemd_postun_with_restart:1}
    %systemd_postun_with_restart ovn-controller-vtep.service
%else
    /bin/systemctl daemon-reload >/dev/null 2>&1 || :
    if [ "$1" -ge "1" ] ; then
        # Package upgrade, not uninstall
        /bin/systemctl try-restart ovn-controller-vtep.service >/dev/null 2>&1 || :
    fi
%endif

%posttrans central
if [ $1 -eq 1 ]; then
    # Package install, not upgrade
    if [ -e %{_localstatedir}/lib/rpm-state/ovn-northd ]; then
        rm %{_localstatedir}/lib/rpm-state/ovn-northd
        /bin/systemctl start ovn-northd.service >/dev/null 2>&1 || :
    fi
fi


%posttrans host
if [ $1 -eq 1 ]; then
    # Package install, not upgrade
    if [ -e %{_localstatedir}/lib/rpm-state/ovn-controller ]; then
        rm %{_localstatedir}/lib/rpm-state/ovn-controller
        /bin/systemctl start ovn-controller.service >/dev/null 2>&1 || :
    fi
fi

%posttrans vtep
if [ $1 -eq 1 ]; then
    # Package install, not upgrade
    if [ -e %{_localstatedir}/lib/rpm-state/ovn-controller-vtep ]; then
        rm %{_localstatedir}/lib/rpm-state/ovn-controller-vtep
        /bin/systemctl start ovn-controller-vtep.service >/dev/null 2>&1 || :
    fi
fi

%files
%{_bindir}/ovn-nbctl
%{_bindir}/ovn-sbctl
%{_bindir}/ovn-trace
%{_bindir}/ovn-detrace
%{_bindir}/ovn_detrace.py
%{_bindir}/ovn-appctl
%{_bindir}/ovn-ic-nbctl
%{_bindir}/ovn-ic-sbctl
%dir %{_datadir}/ovn/
%dir %{_datadir}/ovn/scripts/
%{_datadir}/ovn/scripts/ovn-ctl
%{_datadir}/ovn/scripts/ovn-lib
%{_datadir}/ovn/scripts/ovndb-servers.ocf
%{_mandir}/man8/ovn-ctl.8*
%{_mandir}/man8/ovn-appctl.8*
%{_mandir}/man8/ovn-nbctl.8*
%{_mandir}/man8/ovn-ic-nbctl.8*
%{_mandir}/man8/ovn-trace.8*
%{_mandir}/man1/ovn-detrace.1*
%{_mandir}/man7/ovn-architecture.7*
%{_mandir}/man8/ovn-sbctl.8*
%{_mandir}/man8/ovn-ic-sbctl.8*
%{_mandir}/man5/ovn-nb.5*
%{_mandir}/man5/ovn-ic-nb.5*
%{_mandir}/man5/ovn-sb.5*
%{_mandir}/man5/ovn-ic-sb.5*
%dir %{ovnlibdir}/ocf/resource.d/ovn/
%{ovnlibdir}/ocf/resource.d/ovn/ovndb-servers
%config(noreplace) %verify(not md5 size mtime) %{_sysconfdir}/logrotate.d/ovn
%config(noreplace) %verify(not md5 size mtime) %{_sysconfdir}/sysconfig/ovn

%files central
%{_bindir}/ovn-northd
%{_bindir}/ovn-ic
%{_mandir}/man8/ovn-northd.8*
%{_mandir}/man8/ovn-ic.8*
%{_datadir}/ovn/ovn-nb.ovsschema
%{_datadir}/ovn/ovn-ic-nb.ovsschema
%{_datadir}/ovn/ovn-sb.ovsschema
%{_datadir}/ovn/ovn-ic-sb.ovsschema
%{_unitdir}/ovn-northd.service
%{ovnlibdir}/firewalld/services/ovn-central-firewall-service.xml

%files host
%{_bindir}/ovn-controller
%{_mandir}/man8/ovn-controller.8*
%{_unitdir}/ovn-controller.service
%{ovnlibdir}/firewalld/services/ovn-host-firewall-service.xml

%files vtep
%{_bindir}/ovn-controller-vtep
%{_mandir}/man8/ovn-controller-vtep.8*
%{_unitdir}/ovn-controller-vtep.service

%changelog
* Fri Nov 25 2022 Xavier Simonart <xsimonar@redhat.com> - 22.03.0-125
- controller: Fixed ovs/ovn(features) connection lost when running more than 120 seconds (#2144084)
[Upstream: 730dd68eb10d4488c1822f147852118fbc49e6e4]

* Thu Nov 24 2022 Dumitru Ceara <dceara@redhat.com> - 22.03.0-124
- ovs: Bump submodule to include latest fixes.
[Upstream: cf47ef3be74c5f2321eb550476633bd29bed7de3]

* Tue Nov 22 2022 Xavier Simonart <xsimonar@redhat.com> - 22.03.0-123
- ovn-controller: Fixed missing flows after interface deletion (#2129866)
[Upstream: 22837138f093e7c3d4ee4c4f2f367fb19fc06398]

* Tue Nov 22 2022 Xavier Simonart <xsimonar@redhat.com> - 22.03.0-122
- ovn-controller: Fix releasing wrong vif
[Upstream: 6fbdf81cee8430c98222386d00242cfa5aa0590e]

* Tue Nov 22 2022 Xavier Simonart <xsimonar@redhat.com> - 22.03.0-121
- tests: Fix flaky test "multi-vtep SB Chassis encap updates"
[Upstream: c8bd5ad45130275155bac01feb3493f2bb548f3b]

* Fri Nov 18 2022 Ilya Maximets <i.maximets@ovn.org> - 22.03.0-120
- controller: Fix QoS for ports with undetected or too low link speed. (#2136716)
[Upstream: b47ba92dd33df5452c57d09e733adcee72d145b7]

* Tue Nov 15 2022 Mark Michelson <mmichels@redhat.com> - 22.03.0-119
- ovn-controller: Fix some issues with CT zone assignment. (#2126406)
[Upstream: b81a64293470bb4d61c024403a4cbeef522eb342]

* Tue Nov 01 2022 Mohammad Heib <mheib@redhat.com> - 22.03.0-118
- OVN-CI: Add test cases with monitor-all enabled.
[Upstream: 1e2b0882117b3a50ba943edd399703daca7a2415]

* Tue Nov 01 2022 Mohammad Heib <mheib@redhat.com> - 22.03.0-117
- OVN-CI: remove ddlog test cases.
[Upstream: 91e1196d976cda8776eeafffd9b7978bda30500e]

* Tue Nov 01 2022 Xavier Simonart <xsimonar@redhat.com> - 22.03.0-116
- Added test cases with ovn-northd parallelization enabled
[Upstream: 6c415389b41a291015ab9c9eb39356676f7a88b8]

* Thu Oct 27 2022 Dumitru Ceara <dceara@redhat.com> - 22.03.0-115
- tests: Avoid matching on the OVS flow key contents.
[Upstream: 6d00a3ec49d27ad3ec3cf7850e0d97f05674c954]

* Fri Oct 21 2022 Xavier Simonart <xsimonar@redhat.com> - 22.03.0-114
- ovs: Bump submodule to tip of branch-3.0 and add related test (#2126450)
[Upstream: 68e0100236f1db0dfbfbd27e57495824293b7b23]

* Fri Oct 21 2022 Ales Musil <amusil@redhat.com> - 22.03.0-113
- ci: Add missing tests after switch to parallel jobs
[Upstream: 54ed044f29dfb8d74dbabda4675022ae3c9ffaa8]

* Fri Oct 21 2022 Mohammad Heib <mheib@redhat.com> - 22.03.0-112
- OVN-CI: ovn unit tests run in parallel jobs. (#2114862)
[Upstream: e058edccfdc50ffaa29860025694fea174dde12e]

* Fri Oct 21 2022 Mohammad Heib <mheib@redhat.com> - 22.03.0-111
- CI-Actions: define matrix as a list
[Upstream: ad82452b5c89c07a3fba70ecfd39d743aebfaae5]

* Fri Oct 21 2022 Ales Musil <amusil@redhat.com> - 22.03.0-110
- ci: Use CFLAGS instead of OVS_CFLAGS
[Upstream: 0abb16497334f66469e197b067a15babcb48358c]

* Fri Oct 21 2022 Igor Zhukov <ivzhukov@sbercloud.ru> - 22.03.0-109
- Build tests with asan and ubsan together to reduce CI time.
[Upstream: 521c671faf147ea56d21ed45eb85c68820d5e139]

* Fri Oct 21 2022 Dumitru Ceara <dceara@redhat.com> - 22.03.0-108
- ci: Add UB Sanitizer.
[Upstream: d1466783e8a5ef5931168fd19eb74c525872dc58]

* Thu Oct 20 2022 Ales Musil <amusil@redhat.com> - 22.03.0-107
- controller: Add delay after multicast ARP packet
[Upstream: 73c5886aafc6f9f815008a4c0cacbc7331356e2b]

* Wed Oct 05 2022 Lorenzo Bianconi <lorenzo.bianconi@redhat.com> - 22.03.0-106
- controller: fix ipv6 prefix delegation in gw router mode (#2129244 2129247)
[Upstream: dcf50d75d829ab02ad22ed0598f0d4bc9ae6febc]

* Wed Oct 05 2022 Vladislav Odintsov <odivlad@gmail.com> - 22.03.0-105
- spec: require python3-openvswitch for ovn-detrace
[Upstream: f87e14f0e81122e5b27c3b6f9f04b7af6269be96]

* Mon Oct 03 2022 Mark Michelson <mmichels@redhat.com> - 22.03.0-104
- northd: Use separate SNAT for already-DNATted traffic.
[Upstream: aa8c6d8725581905dc1c0b2259a63cd85b04962f]

* Fri Sep 30 2022 Ales Musil <amusil@redhat.com> - 22.03.0-103
- controller: Restore MAC and vlan for DVR scenario (#2123837)
[Upstream: 33e3be71a62f6fc3ef15b562609dbe1bc87dc682]

* Fri Sep 30 2022 Xavier Simonart <xsimonar@redhat.com> - 22.03.0-102
- northd: Fix multicast table full (#2094710)
[Upstream: 9ab131634868bf407228f0089998547768aa8ea3]

* Wed Sep 28 2022 Dumitru Ceara <dceara@redhat.com> - 22.03.0-101
- github: ovn-kubernetes: Update go, kube and libovsdb versions.
[Upstream: 130a8d3957803c1b59e4a30a9d27d7c5440947dd]

* Wed Sep 28 2022 Dumitru Ceara <dceara@redhat.com> - 22.03.0-100
- ci: ovn-kubernetes: Align CI jobs with recent ovn-kubernetes upstream.
[Upstream: e520418d1763b19e8f83ea9d9d7c57f6ab7dda76]

* Wed Sep 28 2022 Xavier Simonart <xsimonar@redhat.com> - 22.03.0-99
- controller: Fix first ping from lsp to external through snat failing (#2130046)
[Upstream: 8706146f45914d86889a2c446d83c61bbd124794]

* Mon Sep 26 2022 Ales Musil <amusil@redhat.com> - 22.03.0-98
- northd: Do not report WARN for empty requested-chassis (#2126400)
[Upstream: bc8691d79c510cf593a1837d566e0499ccd5b11d]

* Mon Sep 26 2022 Lucas Alvares Gomes <lucasagomes@gmail.com> - 22.03.0-97
- Allow for setting the Next server IP in the DHCP header (#2083629)
[Upstream: 34c04168372494823809cdcc52f4a94fb2513226]

* Thu Sep 22 2022 Dumitru Ceara <dceara@redhat.com> - 22.03.0-96
- NEWS: Fix NEWS file.
[Upstream: 0932c649cbe9d90b90853b9af2af5a96be9b46fb]

* Mon Sep 19 2022 Mark Michelson <mmichels@redhat.com> - 22.03.0-95
- Revert "ovn-controller: fix a crash when deleting a port claimed when sb was ro"
[Upstream: c2e8de38242cf0e21769692b6411cfc09257eac8]

* Fri Sep 16 2022 Xavier Simonart <xsimonar@redhat.com> - 22.03.0-94
- ovn-controller: fix a crash when deleting a port claimed when sb was ro
[Upstream: dc1288aef481d0d234256b2ccd0f7d08b4234e38]

* Fri Sep 16 2022 Vladislav Odintsov <odivlad@gmail.com> - 22.03.0-93
- controller: flush associated conntrack zone on PB release
[Upstream: f0a5f73850249060fa1f1d88c8c5130326a775da]

* Fri Sep 16 2022 Dumitru Ceara <dceara@redhat.com> - 22.03.0-92
- Bump required python version to 3.6.
[Upstream: e292e13765451a733d15075f0e949e92deeb18e2]

* Fri Sep 16 2022 Dumitru Ceara <dceara@redhat.com> - 22.03.0-91
- tests: Fix tests/check_acl_log.py outputs.
[Upstream: bc0ceedaca8839fd15ffc2e923192b50b1e9dfec]

* Thu Sep 15 2022 Vladislav Odintsov <odivlad@gmail.com> - 22.03.0-90
- northd: don't include disabled LSP's IP to Load Balancing
[Upstream: 7341c10f88bc96aab5be9650c4fb5309d6e77589]

* Fri Sep 09 2022 Dumitru Ceara <dceara@redhat.com> - 22.03.0-89
- tests: Add missing reset_pcap_file() definition.
[Upstream: 4bd9fbfa61d3f9ffdd1ebcb97306fd83fdd19c99]

* Thu Sep 08 2022 Han Zhou <hzhou@ovn.org> - 22.03.0-88
- Don't blindly save original dst IP and Port to avoid megaflow unwildcarding.
[Upstream: 00fcddd0162ab0ceda7eb2fdaa2d98f3b5937676]

* Mon Aug 29 2022 Xavier Simonart <xsimonar@redhat.com> - 22.03.0-87
- controller: fix potential segmentation violation when removing ports
[Upstream: add4972e24bd48a08f5c32642b709e08cf5bbe7b]

* Fri Aug 19 2022 Mohammad Heib <mheib@redhat.com> - 22.03.0-86
- binding.c: update ld->peers when lsp type updated (#2077078)
[Upstream: bad4a849227decf85b14bf8fea0e4cb8de25579b]

* Wed Aug 17 2022 Olaf Seibert <o.seibert@syseleven.de> - 22.03.0-85
- northd: Fix memory leak.
[Upstream: a407c9b9e924c67b72dc47c578324c577aed1a44]

* Wed Aug 17 2022 Ihar Hrachyshka <ihrachys@redhat.com> - 22.03.0-84
- controller: throttle port claim attempts
[Upstream: 2c98163e024f0543d84df44f9c0840ce0347e2bc]

* Wed Aug 17 2022 Ihar Hrachyshka <ihrachys@redhat.com> - 22.03.0-83
- Split out code to handle port binding db updates
[Upstream: 3af319c8ef5e732f4d1159ca23c276e0846b9003]

* Tue Aug 09 2022 Dumitru Ceara <dceara@redhat.com> - 22.03.0-82
- northd: Do not relay local IP multicast (224.0.0.X). (#2077306)
[Upstream: b70e75f87117f8c8f1ae97665b745c0f31a918bf]

* Tue Aug 09 2022 Han Zhou <hzhou@ovn.org> - 22.03.0-81
- extend-table: Fix table ID double allocation after OVS restart. (#2112111)
[Upstream: 4826a19fae7a0d6f33df6e6fcd20567878acc753]

* Tue Aug 09 2022 Han Zhou <hzhou@ovn.org> - 22.03.0-80
- ofctrl.c: Use bundle to avoid data plane downtime during the first flow installation.
[Upstream: ebfbedd0ceda723d5f78773c965529ee136a5720]

* Tue Aug 09 2022 Han Zhou <hzhou@ovn.org> - 22.03.0-79
- ofctrl.c: Include group changes to bundle.
[Upstream: 9a0e90be73af6f9d16765286d1c1734e91bc7d8d]

* Tue Aug 09 2022 Han Zhou <hzhou@ovn.org> - 22.03.0-78
- ofctrl: Support ovn-ofctrl-wait-before-clear to reduce down time during upgrade.
[Upstream: 4a34b878d02464266c2b7ff2779de121b130e065]

* Tue Aug 09 2022 Han Zhou <hzhou@ovn.org> - 22.03.0-77
- ofctrl: Wakeup when entering S_UPDATE_FLOWS.
[Upstream: 8684a9424875d97b14f518903ff8c3575ed5dd9f]

* Mon Aug 08 2022 Ihar Hrachyshka <ihrachys@redhat.com> - 22.03.0-76
- tests: Enable vif-plug tests and fix the vif-provider.
[Upstream: a325d9c32a8253a4475faab49c82002144b1497b]

* Mon Aug 08 2022 Ales Musil <amusil@redhat.com> - 22.03.0-75
- ovn-ctl: Ensure that log/run directory have correct permission (#2113855)
[Upstream: 27fb6d440ec74636909d9e3a2ded06ea523cb3c3]

* Tue Aug 02 2022 Ihar Hrachyshka <ihrachys@redhat.com> - 22.03.0-74
- qos: add support for port minimum bandwidth guarantee (#2060310)
[Upstream: a27f077773c9638c77bb4ce32eaf168cd168ca6b]

* Tue Aug 02 2022 Ihar Hrachyshka <ihrachys@redhat.com> - 22.03.0-73
- tests: check qos_max_rate and qos_burst are set
[Upstream: 3554c5a6489a975ddc15a4d6df0fd9894cabb3ce]

* Tue Aug 02 2022 Ales Musil <amusil@redhat.com> - 22.03.0-72
- controller: Fix IPv6 prefix delegation (#2108726)
[Upstream: ea17a67b55ea4cea916f1efea8ea8a0830a8756a]

* Tue Aug 02 2022 Ales Musil <amusil@redhat.com> - 22.03.0-71
- system-tests: Reduce flakiness of IPv6 prefix delegation (#2108726)
[Upstream: dd0bdf5a5e85a953f4f63a3cc4515c4368b27bb4]

* Tue Aug 02 2022 Mohammad Heib <mheib@redhat.com> - 22.03.0-70
- northd: handle virtual lport type update (#2099288)
[Upstream: ec933537f9b04b35ef4b79fb2b4743f9095da209]

* Thu Jul 21 2022 Numan Siddique <numans@ovn.org> - 22.03.0-69
- Fix compilation issue in fedora 37/rawhide.
[Upstream: 822f78a0ab0deaf27c0576104acacd124fbbd389]

* Tue Jul 19 2022 wangchuanlei <wangchuanlei@inspur.com> - 22.03.0-68
- pinctrl: fix ovn-controller abort when service start.
[Upstream: 16599fb23344d86e00c7d5539a9dc77798d466a8]

* Tue Jul 19 2022 Lorenzo Bianconi <lorenzo.bianconi@redhat.com> - 22.03.0-67
- lflow: fix possible use-after-free in add_lb_vip_hairpin_reply_action
[Upstream: 6e5dc3fffa93e502c0f6584a6e2c71ebc7fddfd1]

* Tue Jul 19 2022 Lorenzo Bianconi <lorenzo.bianconi@redhat.com> - 22.03.0-66
- ovn-ic: do not learn routes with link-local next-hops (#2100355)
[Upstream: d13d1ab4af6f51bfb1bccdb1cc60b7da70753509]

* Mon Jul 11 2022 Dumitru Ceara <dceara@redhat.com> - 22.03.0-65
- ovn-nb: Properly document multicast flood config defaults.
[Upstream: a9f214a71dbc43e1627be3e55541481b3d7c61a5]

* Mon Jul 11 2022 Ales Musil <amusil@redhat.com> - 22.03.0-64
- ovn-nbctl: Fix priority arg of lrp-set-gateway-chassis (#2102930)
[Upstream: 6f0e30b208d85030cfb6272866388d7a290c2bde]

* Thu Jul 07 2022 Vladislav Odintsov <odivlad@gmail.com> - 22.03.0-63
- northd: set svc_mon status to offline if port_binding released (#2103740)
[Upstream: 3a1bb158e4ed25e4439373b46769b11003503912]

* Fri Jul 01 2022 Mark Michelson <mmichels@redhat.com> - 22.03.0-62
- ovs: Bump submodule to newer version (#2102618)
[Upstream: a6bfa463aaa43ab76e3debac27b46edaa1e37087]

* Wed Jun 29 2022 Lorenzo Bianconi <lorenzo.bianconi@redhat.com> - 22.03.0-61
- northd: add condition for stateless nat drop flow in S_ROUTER_IN_GW_REDIRECT pipeline (#2094980)
[Upstream: 187ae17ef1639d132cab7d0cbe546c4e39964bb0]

* Wed Jun 29 2022 Ales Musil <amusil@redhat.com> - 22.03.0-60
- northd.c: Add flow to skip put_nd action if ip6.src or nd.sll is 0
[Upstream: c81559a54e0e205ff3f53c48065d4b57b18f0061]

* Tue Jun 28 2022 Terry Wilson <twilson@redhat.com> - 22.03.0-59
- Allow arbitrary args to be passed to called binary
[Upstream: b1d6d92b83c634049078fbf477436751ced5ccfc]

* Mon Jun 27 2022 Ihar Hrachyshka <ihrachys@redhat.com> - 22.03.0-58
- tests: ovn-nbctl dump-flows -> ovn-sbctl dump-flows
[Upstream: 8423d024d7a3965a722b53fe47ed7f37088c225d]

* Mon Jun 27 2022 Ihar Hrachyshka <ihrachys@redhat.com> - 22.03.0-57
- Fix memleak in ovn-nbctl when args can't be parsed
[Upstream: 9c29f5523360e8f34542dcc10ff7419c5b492858]

* Tue Jun 14 2022 Ihar Hrachyshka <ihrachys@redhat.com> - 22.03.0-56
- Fix pidfile_is_running when $cmd is not passed
[Upstream: 543c23cb74ddc9ee23c1f2214952e76fb4cfb830]

* Thu Jun 09 2022 Ihar Hrachyshka <ihrachys@redhat.com> - 22.03.0-55
- Lock pinctrl_mutex for pinctrl_wait
[Upstream: 6172f6a9bdcd430c56e9be81e42a2899b2e6876c]

* Thu Jun 09 2022 Terry Wilson <twilson@redhat.com> - 22.03.0-54
- Ensure pid belongs to ovsdb-server in ovn-ctl
[Upstream: c45619f5541a885554b974d18a1b088902316b1d]

* Thu Jun 09 2022 Terry Wilson <twilson@redhat.com> - 22.03.0-53
- Handle re-used pids in pidfile_is_running
[Upstream: 11800229022e1445f8a8523a3ca5bb7c2e7c9a90]

* Fri Jun 03 2022 Mark Michelson <mmichels@redhat.com> - 22.03.0-52
- Prepare for 22.03.2.
[Upstream: ef112287c6c063ff915d24cac6e5d5b5af3257a6]

* Fri Jun 03 2022 Mark Michelson <mmichels@redhat.com> - 22.03.0-51
- Set release date for 22.03.1.
[Upstream: 6d3af5241168481880e829bb71f9a3c768db7a83]

* Fri Jun 03 2022 Dumitru Ceara <dceara@redhat.com> - 22.03.0-50
- northd: Use ct_mark.blocked and ecmp_reply_port only when all chassis support it. (#2091565)
[Upstream: c53f339342dbc3f79a34787f153f81989bac9909]

* Fri Jun 03 2022 Dumitru Ceara <dceara@redhat.com> - 22.03.0-49
- northd: ovn-controller: Use ct_mark.natted only when ct_lb_mark is used.
[Upstream: 8ba4efdf219b1e20ed190e16a6af37aa6bdf7a69]

* Wed Jun 01 2022 Dumitru Ceara <dceara@redhat.com> - 22.03.0-48
- northd: Use ct_lb_mark only when all chassis support it. (#2091565)
[Upstream: bab59d76ea96fefac315c522b5ce40928947ce99]

* Fri May 27 2022 Ales Musil <amusil@redhat.com> - 22.03.0-47
- binding.c: Make sure that localport is removed from local datapath (#2076604)
[Upstream: cb2e57060e9d7c4d5d2902e3a61474278a0a4241]

* Fri May 27 2022 Ales Musil <amusil@redhat.com> - 22.03.0-46
- physical.c: Move localport remote output flow definition (#2076604)
[Upstream: 4e9ecbc757419f7fdfdfb88b9c3643dc09f2b2b6]

* Tue May 24 2022 Ales Musil <amusil@redhat.com> - 22.03.0-45
- physical.c: Avoid NULL ptr deref in populate_remote_chassis_macs (#2082341)
[Upstream: d3fbeea8516ea8654b847f0d916d4bbca650ca05]

* Mon May 23 2022 Han Zhou <hzhou@ovn.org> - 22.03.0-44
- Use ct_mark for masked access to make flows HW-offloading friendly. (#1957786)
[Upstream: d1e05296516583e7ed779572729c54ca31fe6c92]

* Mon May 23 2022 Han Zhou <hzhou@ovn.org> - 22.03.0-43
- ovn-controller: Handle SB_Global:options:northd_internal_version in I-P engine.
[Upstream: 4c509ceda237963359a86ceaca645aaa0cf84338]

* Mon May 23 2022 Han Zhou <hzhou@ovn.org> - 22.03.0-42
- ovn-northd: Improve the doc and tests for ecmp-symmetric-reply.
[Upstream: b2281b863560b3841554dba4f5e0328ed406341d]

* Mon May 23 2022 Han Zhou <hzhou@ovn.org> - 22.03.0-41
- actions: Add stack push and pop actions.
[Upstream: e6c50afa9f53068254b86844ec37f18cf121ff09]

* Mon May 23 2022 Han Zhou <hzhou@ovn.org> - 22.03.0-40
- actions: Add action ct_lb_mark.
[Upstream: be66dbb1baec84f0fd14353b65542d7279aeb6ca]

* Mon May 23 2022 Han Zhou <hzhou@ovn.org> - 22.03.0-39
- ovn-sb.xml: Fix ct_lb documentation.
[Upstream: d48ff8f749efed273d9a08bfaeb22d0954d34b7d]

* Thu May 19 2022 Lorenzo Bianconi <lorenzo.bianconi@redhat.com> - 22.03.0-38
- northd: fix stateless nat with allowed_ext_ips (#2066990)
[Upstream: fc2cdb499023676e8faf9e368746896166d29114]

* Wed May 18 2022 Dumitru Ceara <dceara@redhat.com> - 22.03.0-37
- ovn-controller: Consider zone 0 as a valid zone when restoring. (#2087194)
[Upstream: 7d6d67c824accf8b07a1da0e11c0aa70e8f22431]

* Wed May 18 2022 Mary Manohar <mary.manohar@nutanix.com> - 22.03.0-36
- ovn-controller: Set Port_Binding.up field only if the Southbound DB is aware of this field
[Upstream: 56a836ce24271a19a0e17e5ac2f70b15e8c8dde9]

* Wed May 18 2022 Mark Michelson <mmichels@redhat.com> - 22.03.0-35
- northd: Honor ct-snat-zone option for common case. (#2061619)
[Upstream: f93e36c8e3a30acbbe21c8641b8a4d48289578f0]

* Mon May 16 2022 Mohammad Heib <mheib@redhat.com> - 22.03.0-34
- northd: handle container lport type update (#2037433)
[Upstream: 28d40c0a024227c9c845117087b7594723ff0ec7]

* Mon May 16 2022 Lorenzo Bianconi <lorenzo.bianconi@redhat.com> - 22.03.0-33
- northd: fix lflow grouping in build_lb_rules
[Upstream: bfa80196810b3c1306cdb00a032fcc7fb54ba025]

* Thu May 12 2022 Han Zhou <hzhou@ovn.org> - 22.03.0-32
- ovn-controller: Avoid recompute triggered by external_ids:ovn-installed update.
[Upstream: fcbe70bb7746f7ff7b6f6481a4446ebaf600b030]

* Wed May 11 2022 Ihar Hrachyshka <ihrachys@redhat.com> - 22.03.0-31
- docs: fix a typo in bandwidth column name
[Upstream: d41054fcc4926e553139ef4ab13ae65c3f009fcb]

* Wed May 11 2022 Ales Musil <amusil@redhat.com> - 22.03.0-30
- ci: ovn-kubernetes: Add missing socat package
[Upstream: 83d07fee947183253ec95c448b39d62aa6001d7f]

* Tue May 10 2022 Lorenzo Bianconi <lorenzo.bianconi@redhat.com> - 22.03.0-29
- utilities: ovn-trace: fix reject action crash (#2074537)
[Upstream: fa7d86a8ae43fa208ef9a3980af396c1feaec92f]

* Tue May 10 2022 Lorenzo Bianconi <lorenzo.bianconi@redhat.com> - 22.03.0-28
- utilities: nbctl: do not report errors for stateless nat if --may-exist is provided (#2066551)
[Upstream: ecd073a49eaec04db7de729a087410477e5811bb]

* Tue May 10 2022 Ales Musil <amusil@redhat.com> - 22.03.0-27
- lflow: Add MAC bindings when new datapath is added to chassis (#2069783)
[Upstream: ff1e858c99779bdbd48fc4b0d0a1fb39bc9606b9]

* Mon May 09 2022 Lorenzo Bianconi <lorenzo.bianconi@redhat.com> - 22.03.0-26
- northd: fix nat-v6 with exempted_ext_ips configuration (#2066611)
[Upstream: 39034eea28cc4b8f79e6af3844fd0d1b7f680bd6]

* Mon May 09 2022 Lorenzo Bianconi <lorenzo.bianconi@redhat.com> - 22.03.0-25
- northd: dynamically compute l2 hdr len for check_pkt_larger action (#2075121)
[Upstream: 4f3656a20c7756f8ab9a7acae5ec192d37c1bf45]

* Thu May 05 2022 Han Zhou <hzhou@ovn.org> - 22.03.0-24
- binding.c: Clear Port_Binding's encap column when encap-ip is removed.
[Upstream: 83c737e1741b24a58e1df333532529c9afb117a5]

* Thu May 05 2022 Dumitru Ceara <dceara@redhat.com> - 22.03.0-23
- northd: Mark most of the SB columns as write-changed-only. (#2069623)
[Upstream: c7071900c55d20160e3f2f2241059a8e8dd6a107]

* Tue Apr 26 2022 Adrian Moreno <amorenoz@redhat.com> - 22.03.0-22
- parallel-hmap: rewrite iterator using multivar helpers
[Upstream: 3da85a6660776548ddafaa9759b260b0dac38b4b]

* Tue Apr 26 2022 Adrian Moreno <amorenoz@redhat.com> - 22.03.0-21
- treewide: bump ovs and fix problematic loops
[Upstream: 985ef4580ac6558859e104bad6fd5e2a68af79f7]

* Tue Apr 26 2022 Mark Michelson <mmichels@redhat.com> - 22.03.0-20
- Get OVS branch updated to proper base version for upcoming changes.
[Upstream: 367051dacab28dbe875aba9e1920b5693cf284c3]

* Mon Apr 25 2022 Numan Siddique <numans@ovn.org> - 22.03.0-19
- ovn-northd: Add flow to use eth.src if nd.tll is 0 in put_nd() action. (#2078026)
[Upstream: bd0ee4c1103ca5eaf834e48093205cacddaadf31]

* Thu Apr 21 2022 Ihar Hrachyshka <ihrachys@redhat.com> - 22.03.0-18
- Stop sending garps when binding not bound to chassis
[Upstream: 65088824dbca07dfdf3402d1775d3af76a304ef4]

* Thu Apr 21 2022 Ales Musil <amusil@redhat.com> - 22.03.0-17
- pinctrl.c: Send GARP only on chassis atached to l3gw (#2062580)
[Upstream: 77ec310dda51c78c1897011ba851612787fcc6c6]

* Sun Apr 17 2022 Lorenzo Bianconi <lorenzo.bianconi@redhat.com> - 22.03.0-16
- system-ovn: fix CoPP test failures (#2073060)
[Upstream: 388446ff27650773716ebcbc332424b1bf82bad1]

* Wed Apr 13 2022 Han Zhou <hzhou@ovn.org> - 22.03.0-15
- ofctrl.c: Check installed flow when merging tracked flow changes. (#2071272)
[Upstream: 92cdada0e150e937e19f52c98a0c6a6dba7a84e0]

* Mon Apr 11 2022 Xavier Simonart <xsimonar@redhat.com> - 22.03.0-14
- northd: avoid writing to IDL in parallel when using northd parallelization
[Upstream: 6410cb7906121bf2ebec3698d53bcfcb580ca4f6]

* Thu Apr 07 2022 Mohammad Heib <mheib@redhat.com> - 22.03.0-13
- controller/pinctrl: avoid accessing invalid memory (#2052945)
[Upstream: 55a0ab5d2971daaf22e3d935f623bf7548a3df98]

* Thu Apr 07 2022 Xavier Simonart <xsimonar@redhat.com> - 22.03.0-12
- northd: avoid snat on reply packets (#2061593)
[Upstream: be49d5145e10b1e4a525eed3b12d7ffb7818f2d1]

* Wed Apr 06 2022 Vladislav Odintsov <odivlad@gmail.com> - 22.03.0-11
- vtep: correctly bring vtep lport up in SBDB
[Upstream: 655c3aa74d45791b0de5548c787ee24a147f2456]

* Wed Apr 06 2022 Lorenzo Bianconi <lorenzo.bianconi@redhat.com> - 22.03.0-10
- controller: properly remove qos policy meters
[Upstream: a814b865fbec460c91f9b5037d936b9d518c7a2f]

* Wed Mar 30 2022 Mark Michelson <mmichels@redhat.com> - 22.03.0-9
- tests: Make "check CoPP config" more reliable.
[Upstream: 93e21802ac27ed29f2a4daf58a10912ebd581db5]

* Tue Mar 29 2022 Dumitru Ceara <dceara@redhat.com> - 22.03.0-8
- inc-proc-eng: Properly log recompute reason.
[Upstream: 3b07a5db4abd921a87b6fdfb851cf27e6975b079]

* Thu Mar 24 2022 Mark Michelson <mmichels@redhat.com> - 22.03.0-7
- NEWS: Update the 22.03.0 release date.
[Upstream: e62886efda51adadd6c01c4e7ee0bbd97994216c]

* Thu Mar 24 2022 Vladislav Odintsov <odivlad@gmail.com> - 22.03.0-6
- rhel: fix logrotate user config option
[Upstream: 135310cae98e84a637f13e99439566846debcb29]

* Thu Mar 17 2022 Dumitru Ceara <dceara@redhat.com> - 22.03.0-5
- northd: Properly warn for NAT on LR with multiple gw ports.
[Upstream: 622d15d078178e854027358d5130690edbe75a4c]

* Fri Mar 11 2022 Mark Michelson <mmichels@redhat.com> - 22.03.0-4
- Prepare for 22.03.1.
[Upstream: b3d273f73c4aa8d246e652f1fb505779d3828c5b]

